@@ -1,11 +1,11 @@
 /* clp.c - Complete source code for CLP.
-   Copyright (C) 1997-9 Eddie Kohler, eddietwo@lcs.mit.edu
+   Copyright (C) 1997-2001 Eddie Kohler, eddietwo@lcs.mit.edu
    This file is part of CLP, the command line parser package.
 
-   CLP is free software. It is distributed under the GNU Public License,
-   version 2 or later; you can copy, distribute, or alter it at will, as
-   long as this notice is kept intact and this source code is made available.
-   There is no warranty, express or implied. */
+   CLP is free software. It is distributed under the GNU Lesser General Public
+   License, version 2 or later; you can copy, distribute, or alter it at will,
+   as long as this notice is kept intact and this source code is made
+   available. There is no warranty, express or implied. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -355,7 +355,7 @@ Clp_SetOptionChar(Clp_Parser *clp, int c, int option_type)
 	have_short[cli->opt[i].short_name] = 1;
       for (i = 0; i < cli->nopt; i++)
 	if (cli->opt[i].long_name && cli->long_min_match[i].pos == 1) {
-	  // if `--Cxxxx's short name is `-C', keep long_min_match == 1
+	  /* if `--Cxxxx's short name is `-C', keep long_min_match == 1 */
 	  unsigned char first = (unsigned char)cli->opt[i].long_name[0];
 	  if (have_short[first] && first != cli->opt[i].short_name)
 	    cli->long_min_match[i].pos++;
