@@ -6,6 +6,7 @@
 #include "tile.hh"
 #include "tileset.hh"
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 
 Tile Game::the_null_tile;
@@ -493,8 +494,8 @@ Game::layout_kyodai_file(FILE *f)
 bool
 Game::layout_young_file(FILE *f)
 {
+  char buffer[BUFSIZ];
   while (!feof(f)) {
-    char buffer[BUFSIZ];
     buffer[0] = 0;
     fgets(buffer, BUFSIZ, f);
     int r, c, l;
@@ -505,6 +506,45 @@ Game::layout_young_file(FILE *f)
   return true;
 }
 
+bool
+Game::layout_kmahjongg_file(FILE *f)
+{
+  char buf[BUFSIZ];
+
+  // check for `kmahjongg-layout'
+  buf[0] = 0;
+  fgets(buf, BUFSIZ, f);
+  if (memcmp(buf, "kmahjongg-layout-v1", 19) != 0) {
+    fprintf(stderr, "not a kmahjongg layout file\n");
+    return false;
+  }
+
+  // now read file
+  int l = 0;
+  while (!feof(f) && l < TILE_LEVS - 1) {
+    for (int r = 0; r < 16 && !feof(f); r++) {
+      buf[0] = 0;
+      fgets(buf, BUFSIZ, f);
+      for (int c = 0; c < TILE_COLS - 3 && buf[c] && !isspace(buf[c]); c++)
+	if (buf[c] == '1') {
+	  if (!place_tile(r + 2, c + 2, l))
+	    return false;
+	} else if (buf[c] == '2' || buf[c] == '3' || buf[c] == '4'
+		   || buf[c] == '.')
+	  /* ok */;
+	else if (buf[c] == '#')
+	  break;
+	else {
+	  fprintf(stderr, "bad character\n");
+	  return false;
+	}
+    }
+    l++;
+  }
+  
+  return true;
+}
+
 int
 Game::layout_file(const char *filename)
   /* returns -1 on system error, 0 on other error, 1 on no error */
@@ -519,6 +559,8 @@ Game::layout_file(const char *filename)
   ungetc(c, f);
   if (c == 'K')
     ok = layout_kyodai_file(f);
+  else if (c == 'k')
+    ok = layout_kmahjongg_file(f);
   else
     ok = layout_young_file(f);
   
