@@ -4,6 +4,7 @@
 #include "xmj3ts.hh"
 #include "gmjts.hh"
 #include "kmjts.hh"
+#include "kdets.hh"
 #include "board.hh"
 #include "panel.hh"
 #include "game.hh"
@@ -21,6 +22,7 @@
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
+#include <time.h>
 #include "gif.h"
 #include "gifx.h"
 #include "clp.h"
@@ -415,24 +417,46 @@ load_tileset(const char *tileset_name, const char *config_dir)
     fclose(f);
   }
   
-  Tileset *tileset;
-  if (!gfs)
-    tileset = 0;
-  else if (Gif_ImageCount(gfs) == 1) {
-    Gif_Image *gfi = Gif_GetImage(gfs, 0);
-    if (Gif_ImageWidth(gfi) > 2*Gif_ImageHeight(gfi))
-      tileset = new GnomeMjTileset(gfs, gifx);
-    else
-      tileset = new KMjTileset(gfs, gifx);
-  } else
+  Tileset *tileset = 0;
+
+  // Xmahjongg tileset?
+  if (gfs && !tileset && Gif_ImageCount(gfs) > 1)
     tileset = new Xmj3Tileset(gfs, gifx);
+
+  // Otherwise, check dimensions.
+  int width = 0, height = 0;
+  if (gfs && !tileset) {
+    Gif_Image *gfi = Gif_GetImage(gfs, 0);
+    width = (gfi ? Gif_ImageWidth(gfi) : 0);
+    height = (gfi ? Gif_ImageHeight(gfi) : 0);
+  }
+
+  // Gnome tileset?
+  if (gfs && !tileset && width > 2*height)
+    tileset = new GnomeMjTileset(gfs, gifx);
+
+  // KDE tileset?
+  if (gfs && !tileset && width == 360 && height == 280) {
+    tileset = new KDETileset(gfs, gifx);
+    if (!tileset->ok()) {
+      delete tileset;
+      tileset = 0;
+    }
+  }
+
+  // Kyodai tileset?
+  if (gfs && !tileset)
+    tileset = new KyodaiTileset(gfs, gifx);
+
+  // Delete tileset if bad
   if (tileset && !tileset->ok()) {
     delete tileset;
     tileset = 0;
   }
   
   delete[] buf;
-  if (gfs && !gfs->refcount) Gif_DeleteStream(gfs);
+  if (gfs && !gfs->refcount)
+    Gif_DeleteStream(gfs);
   
   // What if that's not a valid tileset?
   if (!tileset) {
@@ -621,8 +645,8 @@ particular purpose.\n");
   Window window = create_window(display, screen_number, background);
   if (window == None) fatal_error("could not create window");
   XSelectInput(display, window, ExposureMask | ButtonPressMask
-	       | KeyPressMask | KeyReleaseMask | StructureNotifyMask
-	       | Button2MotionMask);
+	       | ButtonReleaseMask | KeyPressMask | KeyReleaseMask
+	       | StructureNotifyMask | Button2MotionMask);
   
   Panel *panel = new Panel(display, window);
   make_panel_images(panel);
