@@ -252,7 +252,7 @@ Panel::tile_command(Game *g, Tile *t)
 
 
 void
-Panel::command(Game *g, Command com, Button *button, bool keyboard)
+Panel::command(Game *g, Command com, Button *button, bool keyboard, Time when = CurrentTime)
 {
   if (com != comHint)
     _board->hint()->turn_off();
@@ -263,9 +263,10 @@ Panel::command(Game *g, Command com, Button *button, bool keyboard)
   _traversal->turn_off();
   
   if (keyboard) {
-    if (button) button->flash();
+    if (button)
+      button->flash();
   } else {
-    if (button && !button->track())
+    if (button && !button->track(when))
       return;
   }
   
@@ -383,22 +384,22 @@ Panel::traversal_command(Game *g, TraversalCommand command)
 
 
 void
-Panel::click(Game *g, int x, int y, unsigned state)
+Panel::click(Game *g, int x, int y, unsigned state, Time when)
 {
   if (Tile *t = _board->find_tile(x, y))
     tile_command(g, t);
   else if (hint_but->within(x, y))
-    command(g, comHint, hint_but, false);
+    command(g, comHint, hint_but, false, when);
   else if (undo_but->within(x, y))
-    command(g, state & ShiftMask ? comRedo : comUndo, undo_but, false);
+    command(g, state & ShiftMask ? comRedo : comUndo, undo_but, false, when);
   else if (new_but->within(x, y))
-    command(g, comNew, new_but, false);
+    command(g, comNew, new_but, false, when);
   else if (quit_but->within(x, y))
-    command(g, comQuit, quit_but, false);
+    command(g, comQuit, quit_but, false, when);
   else if (clean_but->within(x, y))
-    command(g, comClean, clean_but, false);
+    command(g, comClean, clean_but, false, when);
   else
-    command(g, comNone, 0, false);
+    command(g, comNone, 0, false, when);
 }
 
 
@@ -451,7 +452,7 @@ Panel::handle(Game *game, XEvent *e)
     
    case ButtonPress:
     if (e->xbutton.button == 1)
-      click(game, e->xbutton.x, e->xbutton.y, e->xbutton.state);
+      click(game, e->xbutton.x, e->xbutton.y, e->xbutton.state, e->xbutton.time);
     /*else if (e->xbutton.button == 2)
       scan_mark(e->xbutton.x, e->xbutton.y);*/
     break;
